NodeDataDir

Struct NodeDataDir 

pub struct NodeDataDir { /* private fields */ }
Tracks information about where the node-specfic configuration files are stored.

Implementations

Source

impl NodeDataDir

pub fn new(path: PathBuf) -> Self

Initializes the node data directory the given path.

pub fn new_test(dev: Option<u16>) -> Self

Initializes the node data directory to a location suitable for unit/integration tests.

pub fn new_development(network: u16, dev: u16) -> Self

Initializes the node data directory path to the development path for the specified network and node index.

pub fn path(&self) -> &Path

pub fn router_peer_cache_path(&self) -> PathBuf

The location to store the previous peer cache.

pub fn gateway_peer_cache_path(&self) -> PathBuf

pub fn validator_whitelist_path(&self) -> PathBuf

pub fn current_proposal_cache_path(&self) -> PathBuf

The location to store the current proposal cache.

pub fn jwt_secret_path<D: Display>(&self, address: &D) -> PathBuf

The location to store the JWT secret for a given address.